<?php 
/*
Plugin Name: No HTML TinyMCE
Plugin URI: http://www.ctlt.ubc.ca
Description: Plugin to hide Visual/HTML Tab for Pages/Posts WYSIWYG (TinyMCE) for all roles except administrator. 
Version: 1.2.1
Author: CTLT DEV


GNU General Public License, Free Software Foundation <http://creativecommons.org/licenses/GPL/2.0/>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
	
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

add_action('init', 'no_html_tinymce_init');
add_action('admin_menu', 'no_html_tinymce_page');


add_action('admin_init', 'no_html_tinymce_register_init');
function no_html_tinymce_register_init(){
	register_setting( 'no_html_tinymce_options', 'no_html_tinymce_options');	
}

/**
 * no_html_tinymce_init function.
 * Description: Ensure pagenow is pages/posts and that user is NOT administrator to disable HTML/Visual tabs.
 * @access public
 * @return void
 */
function no_html_tinymce_init(){
	global $pagenow; 
	global $current_user;
	
	if($pagenow == 'post-new.php' || $pagenow == 'post.php') {
		$serialize_selected_ids = get_option ( "no_html_tinymce_options");
		
		foreach($serialize_selected_ids as $user_id => $there):
			if($user_id == $current_user->ID):
				add_filter('wp_default_editor','no_html_default_editor');
				wp_enqueue_style('tinymce_nohtml', plugins_url('/no-html-tinymce/no-html-tinymce.css'),'css');
				// wp_enqueue_script('tinymce_nohtml', plugins_url('/no-html-tinymce/no-html-tinymce.js'),array('jquery'));
			endif;
		endforeach;
	}
}

function no_html_tinymce_page() {
	add_users_page('Disable HTML Settings Page', 'Disable HTML', 'manage_options', 'disable_html', 'no_html_tinymce_admin_page');
}

function no_html_tinymce_admin_page() {
	if (!current_user_can('manage_options'))  {
		wp_die( __('You do not have sufficient permissions to access this page.') );
	}

	global $pagenow; 
	if($pagenow == 'users.php' && $_GET['page'] == 'disable_html') {	
		if(is_array( $_POST['no_html_tinymce_options'] ) || $_POST)
			update_option ( 'no_html_tinymce_options', $_POST['no_html_tinymce_options'] );
		
		$no_html_tinymce_options = get_option("no_html_tinymce_options");
		
		?>
		<div class="wrap" id="no-html-tinymce-page">
		<h2 id="no-html-tinymce-header">Disable HTML</h2>
		<br />
		<form id="disable-html-users" method="post" action="users.php?page=disable_html">
		<?php settings_fields('no_html_tinymce_options'); ?>		
		<div class="disable-html-bar">
		<select name="disable-html-action">	
		<?php if ( current_user_can('manage_options') ) { ?>
			<option value="disable-html" selected="selected"><?php _e('Disable HTML'); ?></option>
		<?php } ?>
		</select>
		<input type="submit" value="<?php esc_attr_e('Apply'); ?>" name="disable-html-doaction" id="disable-html-doaction" class="button-secondary" />
		<br /><br />
		</div>
		
		<table class="widefat fixed" cellspacing="0">
		<thead>
		<tr class="thead">
		<td style="width:5%;">Disable HTML</td>
		<td style="width:25%;">Username</td>
		<td style="width:30%;">Name</td>
		<td style="width:35%;">E-mail</td>
		</tr>
		</thead>
		
		<style type="text/css">
		.even_shade{
			background: #f1f1f1;
		}
		</style>
		
		<tbody id="users" class="list:user user-list">
		
		<?php
			$users_of_blog = get_users_of_blog();
			$colour_counter=1;
				if( is_array($users_of_blog) ):
					foreach($users_of_blog as $person):
						$odd_even = ($colour_counter%2) ? "even_shade" : "odd_shade";
						?><tr class='<?php echo $odd_even; ?>' id="tr_<?php echo $person->ID; ?>" >
								<td style="width:5%;"><input id="<?php echo $person->ID; ?>" type="checkbox" name="no_html_tinymce_options[<?php echo $person->ID; ?>]" value="1" <?php echo checked($no_html_tinymce_options[$person->ID],"1"); ?> /></td>
								<td style="width:25%;"><?php echo $person->user_login; ?></td>
								<td style="width:30%;"><?php echo $person->display_name; ?></td>
								<td style="width:35%;"><?php echo $person->user_email; ?></td>
						</tr><?php			
						$colour_counter++;
					endforeach;
				endif;
		?>
		</tbody>
		</table>
		<br />
		<div class="disable-html-bar">
		<select name="disable-html-action">	
		<?php if ( current_user_can('manage_options') ) { ?>
			<option value="disable-html" selected="selected"><?php _e('Disable HTML'); ?></option>
		<?php } ?>
		</select>
		<input type="submit" value="<?php esc_attr_e('Apply'); ?>" name="disable-html-doaction" id="disable-html-doaction" class="button-secondary" />
		<br /><br />
		</div>

		</form>
		
		<?php
	}
}


function no_html_default_editor($editor)
{
	return "tinymce";
}